@@ -29,6 +29,7 @@ use AnyEvent::Handle;
                     $unpacker->reset;
 
                     $buffer = substr($buffer, $nread);
+                    $nread = 0;
                     $succeeded++;
                     next if length($buffer) != 0;
                 }
@@ -64,6 +65,10 @@ AnyEvent::MessagePack - MessagePack stream serializer/deserializer for AnyEvent
 
 AE::MessagePack is MessagePack stream serializer/deserializer for AnyEvent.
 
+=head1 THANKS TO
+
+kazeburo++
+
 =head1 SEE ALSO
 
 L<AnyEvent::Handle>, L<AnyEvent::MPRPC>
